<span class="plugin_link"><a href="{{ link }}"{% if target %} target="{{ target }}"{% endif %} {% if instance_css_classes %} class="{{ instance_css_classes }}"{% endif %}{% if instance_inline_styles %} style="{{ instance_inline_styles }}"{% endif %}>{{ name }}</a></span>